# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = [
    "RecommendationGetResponse",
    "RecommendedModel",
    "RecommendedModelFullHyperparameters",
    "RecommendedModelLoraHyperparameters",
]


class RecommendedModelFullHyperparameters(BaseModel):
    batch_size: int = FieldInfo(alias="batchSize")

    learning_rate_multiplier: float = FieldInfo(alias="learningRateMultiplier")

    n_epochs: int = FieldInfo(alias="nEpochs")


class RecommendedModelLoraHyperparameters(BaseModel):
    batch_size: int = FieldInfo(alias="batchSize")

    learning_rate_multiplier: float = FieldInfo(alias="learningRateMultiplier")

    n_epochs: int = FieldInfo(alias="nEpochs")


class RecommendedModel(BaseModel):
    base_model_id: str = FieldInfo(alias="baseModelId")

    full_hyperparameters: RecommendedModelFullHyperparameters

    lora_hyperparameters: RecommendedModelLoraHyperparameters

    reason_for_recommendation: Optional[str] = FieldInfo(alias="reasonForRecommendation", default=None)

    recommended: bool


class RecommendationGetResponse(BaseModel):
    recommended_models: Optional[List[RecommendedModel]] = None

    snapshot_id: str

    status: Literal["processing", "completed", "failed"]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from premai import PremAI, AsyncPremAI
from tests.utils import assert_matches_type
from premai.types import (
    SnapshotCreateResponse,
    SnapshotCreateFromFilesResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSnapshots:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: PremAI) -> None:
        snapshot = client.snapshots.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: PremAI) -> None:
        snapshot = client.snapshots.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            split_percentage=1,
        )
        assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: PremAI) -> None:
        response = client.snapshots.with_raw_response.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        snapshot = response.parse()
        assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: PremAI) -> None:
        with client.snapshots.with_streaming_response.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            snapshot = response.parse()
            assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_from_files(self, client: PremAI) -> None:
        snapshot = client.snapshots.create_from_files(
            label="x",
            project_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            training_file=b"raw file contents",
            validation_file=b"raw file contents",
        )
        assert_matches_type(SnapshotCreateFromFilesResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create_from_files(self, client: PremAI) -> None:
        response = client.snapshots.with_raw_response.create_from_files(
            label="x",
            project_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            training_file=b"raw file contents",
            validation_file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        snapshot = response.parse()
        assert_matches_type(SnapshotCreateFromFilesResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create_from_files(self, client: PremAI) -> None:
        with client.snapshots.with_streaming_response.create_from_files(
            label="x",
            project_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            training_file=b"raw file contents",
            validation_file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            snapshot = response.parse()
            assert_matches_type(SnapshotCreateFromFilesResponse, snapshot, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSnapshots:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncPremAI) -> None:
        snapshot = await async_client.snapshots.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncPremAI) -> None:
        snapshot = await async_client.snapshots.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            split_percentage=1,
        )
        assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncPremAI) -> None:
        response = await async_client.snapshots.with_raw_response.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        snapshot = await response.parse()
        assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncPremAI) -> None:
        async with async_client.snapshots.with_streaming_response.create(
            dataset_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            snapshot = await response.parse()
            assert_matches_type(SnapshotCreateResponse, snapshot, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_from_files(self, async_client: AsyncPremAI) -> None:
        snapshot = await async_client.snapshots.create_from_files(
            label="x",
            project_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            training_file=b"raw file contents",
            validation_file=b"raw file contents",
        )
        assert_matches_type(SnapshotCreateFromFilesResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create_from_files(self, async_client: AsyncPremAI) -> None:
        response = await async_client.snapshots.with_raw_response.create_from_files(
            label="x",
            project_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            training_file=b"raw file contents",
            validation_file=b"raw file contents",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        snapshot = await response.parse()
        assert_matches_type(SnapshotCreateFromFilesResponse, snapshot, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create_from_files(self, async_client: AsyncPremAI) -> None:
        async with async_client.snapshots.with_streaming_response.create_from_files(
            label="x",
            project_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            training_file=b"raw file contents",
            validation_file=b"raw file contents",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            snapshot = await response.parse()
            assert_matches_type(SnapshotCreateFromFilesResponse, snapshot, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .._types import FileTypes

__all__ = ["SnapshotCreateFromFilesParams"]


class SnapshotCreateFromFilesParams(TypedDict, total=False):
    label: Required[str]
    """Snapshot name shown in the dashboard once the snapshot is created."""

    project_id: Required[str]
    """Project ID that will own the generated snapshot.

    Must match an existing project.
    """

    training_file: Required[FileTypes]
    """Required JSONL training file.

    Upload line-delimited messages that will form the training split.
    """

    validation_file: Required[FileTypes]
    """Required JSONL validation file.

    Upload line-delimited messages reserved for validation.
    """
